clc;clear

%% SCRIPT TO CREATE BEHAVIORAL DATA

% This script generates the predictors from the behavioral data recorded 
% for each subject in the folder "data_psycophysics"

% Results are saved in 'P00_data_behavior' folder.
% Results run for all subjects at the same time

mkdir('P00_data_behavior')

for n_subject=1:20

    n_sub = string(n_subject);
    load(fullfile('data_psychophysics','subject_'+n_sub,'behavior_subject_'+n_sub+'.mat')); 
    savefile1 = 'P00_data_behavior/b_data_subject_'+n_sub+'.mat'; % where to save the predictors
    
    %% Predictors: initialize
    
    reaction_time = [];
    match = [];
    board_size = [];
    position_x = [];
    position_y = [];
    distance = [];
    image_category = [];
    n_times_seen = [];
    n_since_pair = [];
    x_chance = [];
    n_since_last_click = [];
    random_match = [];
    unseen_unmatch = [];
    
    %% Compute predictors
    
    for i_board = 1:length(behavior)
        
        % Behavioral parameters from the game
        board_status = behavior(i_board).piece_status; 
        piece_click = behavior(i_board).piece_number;
        subject_score = behavior(i_board).subject_score;
        click_times = behavior(i_board).mouse_click_timing;
        click_position = behavior(i_board).mouse_click_position;
    
        % Check good clicks: if there is more than 1 it means that the piece has been clicked
        good_click_idx = [];
        for i=1:length(board_status)
            if sum(sum(board_status(:, :, i))) > 0
                good_click_idx = [good_click_idx, i];
            end
        end
        
        % Only take features for good clicks
        n_clicks = length(good_click_idx); % total number of clicks
        b_good = board_status(:, :, good_click_idx); % board status only for good clicks
        piece_click = piece_click(good_click_idx); % pieces clicked;
        subject_score = subject_score(good_click_idx);
        click_times = click_times(good_click_idx);
        click_position = click_position(good_click_idx, :);
        
        
        % RT between 1st and 2nd tile
        diff_times_click = diff(click_times); % different between click times
        reaction_time = [reaction_time; diff_times_click(1:2:end)]; % RT only difference between 1st and 2nd click
        
        % Match vs. mismatch: match if subject score increases, mismatch
        % otherwise.
        object_position = behavior(i_board).object_positions'; % position of each object
        object_vector = object_position(:); % convert into vector
        x1s = [];
        % Two options because match and mismatch are different for each subject
        if mod(min(find(subject_score)),2) == 1
            piece1 = piece_click(end-1);
            piece2 = piece_click(end);
            if object_vector(piece1) == object_vector(piece2)
                x1s = [diff(subject_score)', 1];
                match = [match, diff(subject_score)', 1];
            else
                x1s = [diff(subject_score)', 0];
                match = [match, diff(subject_score)', 0];
            end  
        elseif mod(min(find(subject_score)),2) == 0
            piece1 = piece_click(end-1);
            piece2 = piece_click(end);
            x1s = [0, diff(subject_score)'];
            match = [match, 0, diff(subject_score)'];
            if object_vector(piece1) == object_vector(piece2)
                match(end) = 1;
                x1s(end) = 1;
            end
        end
        
        % Board size
        size_b = size(object_position, 1)*size(object_position, 2);
        board_size = [board_size; size_b*ones(size(piece_click))'];
        
        % Position of the tile
        pos_x = click_position(:, 1); pos_y = click_position(:, 2); 
        position_y = [position_y; pos_y];
        position_x = [position_x; pos_x];
        
        % Distance between 1st and 2nd click
        pos_1x = click_position(1:2:end, 1); pos_1y = click_position(1:2:end, 2); % position 1st click
        pos_2x = click_position(2:2:end, 1); pos_2y = click_position(2:2:end, 2); % position 2nd click
        dis_12 = sqrt((pos_1x-pos_2x).^2 + (pos_1y-pos_2y).^2);
        distance = [distance; dis_12];
        
        % Image category
        img_cat = zeros(n_clicks, 1);
        object_position = behavior(i_board).object_positions';
        object_vector = object_position(:);
        image_seen = object_vector(piece_click);
        list_images = behavior(i_board).list_of_images;
        for p=1:n_clicks
            img = image_seen(p); % image seen 
            if img <= length(list_images)
                img_n = list_images(img); % corresponding image
                if img_n<=100 % animal
                   img_cat(p) = 2;
                elseif 100<img_n && img_n<=200 % food
                   img_cat(p) = 3;
                elseif 200<img_n && img_n<=300 % indoor
                   img_cat(p) = 1;
                elseif 300<img_n && img_n<=400 % person 
                   img_cat(p) = 4;
                elseif 400<img_n && img_n<=500 % vehicle
                   img_cat(p) = 5;
                else
                    sprintf("%d, image not found", img_n)
                end  
            else % distractor
                img_cat(p) = 0;
            end
        end
        image_category = [image_category; img_cat];
        
        % N-times-seen: number of times the same image has been seen 
        nts = zeros(n_clicks, 1);
        object_position = behavior(i_board).object_positions';
        object_vector = object_position(:);
        image_seen = object_vector(piece_click);
        n_count = zeros(length(unique(image_seen)), 1);
        for p=1:n_clicks
            img = image_seen(p); % image seen 
            n_times = n_count(img) + 1; % number of times image seen
            n_count(img) = n_times; % update
            nts(p) = n_times;
        end
        n_times_seen = [n_times_seen; nts];
        
        % N-since-pair: how many tiles ago the pair tile was seen
        % X-chance: the first time they have not seen any image
        img_tbl = [image_seen, piece_click']; % image seen and corresponding tile
        x_chances = [];
        nsp = [];
        for i=1:size(img_tbl, 1)
            img_s = image_seen(i); % image they see for the first tile
            tile_s = piece_click(i); % tile they see
            img_seen_before = img_tbl(1:i, :); % take all images they have been seen before this one
            idx = find(img_seen_before(:, 1) == img_s); % check if they have seen this image before
            if length(idx) > 1 % they have seen this image before
                diff_tile = img_seen_before(idx, 2); % check that they saw it at a different position
                if length(unique(diff_tile)) == 2 % they have seen it before
                    idx2 = find(img_seen_before(idx, 2) ~= tile_s); % find it they have seen it at a different tile
                    nsp = [nsp, i-idx(max(idx2))];
                    x_chances = [x_chances, 1];
                else
                    x_chances = [x_chances, 0]; % first time they see it
                    nsp = [nsp, 0];
                end
            else
                x_chances = [x_chances, 0]; % first time they see it 
                nsp = [nsp, 0];
            end
        end
        x_chance = [x_chance, x_chances];
        n_since_pair = [n_since_pair; nsp'];
        
        % N-since-last-click: number of tiles since last time it was clicked
        nslc = zeros(n_clicks, 1);
        n_count = zeros(size(object_position, 1)^2, 1); % nb of times each tile is clicked
        n_seen = zeros(size(object_position, 1)^2, 1); % if seen by first time or not
        for p=1:n_clicks
            piece = piece_click(p); % piece number 
            if n_seen(piece) == 0
                n_seen(piece) = 1; % the image has been seen
                nslc(p) = 0;
                n_count(piece) = 0; % restart the counting
            else  
                nslc(p) = n_count(piece); % # of clicks since last time seen
                n_count(piece) = 0; % reset to zero for this piece
            end
            n_count = n_count + 1;
        end
        n_since_last_click = [n_since_last_click; nslc];
        
    end
    
    % Match: only revealed after the 2nd tile
    match = match(2:2:end)'; 
    
    % whether we have seen the pair of the first tile clicked
    x_chance = x_chance(1:2:end)'; 
    
    % Random match:  
    idx_random_match = intersect(find(match==1), find(x_chance==0)); % matched and pair was not seen before
    random_match = zeros(size(match));
    random_match (idx_random_match) = 1;
    
    % Unseen mismatch: 
    idx_unseen_mismatch = intersect(find(match==0), find(x_chance==0)); % mismatch and pair was not seen before
    unseen_mismatch = zeros(size(match));
    unseen_mismatch(idx_unseen_mismatch) = 1;
    
    % Outliers reaction time: those that are bigger than 5 times the std
    thrs = mean(reaction_time) + 5*std(reaction_time);
    out_rt = find(reaction_time >= thrs);
    length(out_rt);
    
    
    %% Create table
    
    b_data = struct;
    
    % Save name and feature
    b_data(1).name = 'match'; b_data(1).x = match;
    b_data(2).name = 'random_match'; b_data(2).x = random_match;
    b_data(3).name = 'n_since_pair'; b_data(3).x = n_since_pair;
    b_data(4).name = 'n_since_last_click'; b_data(4).x = n_since_last_click;
    b_data(5).name = 'n_times_seen'; b_data(5).x = n_times_seen;
    b_data(6).name = 'reaction_time'; b_data(6).x = reaction_time;
    b_data(7).name = 'board_size'; b_data(7).x = board_size;
    b_data(8).name = 'position_x'; b_data(8).x = position_x;
    b_data(9).name = 'position_y'; b_data(9).x = position_y;
    b_data(10).name = 'distance'; b_data(10).x = distance;
    b_data(11).name = 'image_category'; b_data(11).x = image_category;
    
    % save table
    save(savefile1,'b_data', 'out_rt');
    
end
