function [p2] = plot_bar_board_size(n_fig, b_data_subjects, remove1, feature, tile, p_value, n_permutations, remove_zeros)
    
    % Bar plots of a predictor for match vs. mismatch, for each board size.
    % Permutation test compares whether there is a significant different
    % between match and mismatch for a predictor.
    
    % Input params:
    % n_fig: int, number of the figure to be plotted
    % b_data_subjects: 1xn_sub struct (n_sub:20, totla # of subjects) with
    % 12 fields corresponding to each predictor
    % remove1: 1xn_sub cell (n_sub:20, totla # of subjects), each entry
    % contains artifact trials for each subject
    % feature: char name of the predictor to be selected
    % tile: 1 or 2, for which tile to be computed
    % p_value: alpha, threshold to be considered significant
    % n_permutations: int, number of permutations for permutation test
    % remove_zeros: bool, indicating whether to include zeros or not
    
    % Returns:
    % p2: p_values permutation test comparison

    % organize data
    n_subjects = length(b_data_subjects);
    matches = [];
    board_sizes = [];
    predictors = [];

    for n_sub=1:n_subjects
        match = b_data_subjects(n_sub).('match');
        predictor = b_data_subjects(n_sub).(feature);
        if length(match) < length(predictor)
            predictor = predictor(tile:2:end);
        end
        board = b_data_subjects(n_sub).('board_size');
        board = board(tile:2:end);

        if remove_zeros
            idx_out = find(predictor == 0);
            remove1{n_sub} = union(remove1{n_sub}, idx_out');
        end

        match(remove1{n_sub}) = []; 
        predictor(remove1{n_sub}) = []; 
        board(remove1{n_sub}) = [];

        matches = [matches, match];
        predictors = [predictors, predictor];
        board_sizes = [board_sizes, board];
    end

    % create data to plot
    unique_sizes = unique(board_sizes);
    n_sizes = length(unique_sizes);

    y_plot = zeros(n_sizes, 2);
    err_plot = zeros(n_sizes, 2);
    sig = zeros(n_sizes, 1);

    for n = 1:n_sizes
        trials_in = find(board_sizes == unique_sizes(n));
        match = matches(trials_in);
        predictor = predictors(trials_in);

        match_d = predictor(match==1);
        unmatch_d = predictor(match==0);
        p = permutationTest(match_d, unmatch_d,n_permutations);
        p2(n) = p; 
        if p<=p_value
            h = 1; 
        else
            h = 0;
        end
        sig(n) = h;

        y_plot(n, 1) = mean(match_d);
        y_plot(n, 2) = mean(unmatch_d);
        err_plot(n, 1) = std(match_d)/sqrt(length(match_d));
        err_plot(n, 2) = std(unmatch_d)/sqrt(length(unmatch_d));
    end

    % plot
    figure(n_fig)
    ngroups = n_sizes;
    nbars = 2;

    b = bar(y_plot,'FaceColor','flat');
    
    b(1).FaceColor =[0.33 0.51 0.21]; % green
    %b(1).FaceColor = [1 0.596 0]; % orange
    %b(1).FaceColor = [0.561 0.667 0.863]; % light blue 
    %b(1).FaceColor = [0.787 0.645 0.977]; %light purple 
    
    b(2).FaceColor = [0.5 0.5 0.5];
    xlim([0.5 (n_sizes + 0.5)])
    ylim([0 10])
    xticks = [1:n_sizes];
    names = string(sqrt(unique_sizes));

    hold on; 
    title(['tile ' num2str(tile)]) 
    feature_name = join(split(feature,'_'), '-');
    ylabel([feature_name '(click)']);
    xlabel('Board size');
    groupwidth = min(0.8, nbars/(nbars + 1.5));
    for i = 1:nbars
        x = (1:ngroups) - groupwidth/2 + (2*i-1) * groupwidth / (2*nbars);
        e = errorbar(x, y_plot(:,i), err_plot(:,i), '.');
        e.Color = 'black'; 
        e.CapSize = 2; 
        hold on; 
    end
    for i = 1:ngroups
        if sig(i) == 1
            text(i-0.15,max(max(y_plot))+ max(max(err_plot))+ 1,'*','FontSize',8);
        end
    end

    set(gca,'fontsize', 8,'FontName','Arial','box','off','TickDir','out','xtick',xticks,'xticklabel',names)
    legend({'Match','Mismatch'},'fontsize', 6);

end