function plot_violin_board_size(n_fig, b_data_subjects, remove1, feature, tile, p_value, n_permutations)
    
    % Violin plots of a predictor for match vs. mismatch, for each board size.
    % Permutation test compares whether there is a significant different
    % between match and mismatch for a predictor.

    % Input params:
    % n_fig: int, number of the figure to be plotted
    % b_data_subjects: 1xn_sub struct (n_sub:20, totla # of subjects) with
    % 12 fields corresponding to each predictor
    % remove1: 1xn_sub cell (n_sub:20, totla # of subjects), each entry
    % contains artifact trials for each subject
    % feature: char name of the predictor to be selected
    % tile: 1 or 2, for which tile to be computed
    % p_value: alpha, threshold to be considered significant
    % n_permutations: int, number of permutations for permutation test
    % remove_zeros: bool, indicating whether to include zeros or not

    % organize data
    n_subjects = length(b_data_subjects);
    matches = [];
    board_sizes = [];
    predictors = [];

    for n_sub=1:n_subjects
        match = b_data_subjects(n_sub).('match');
        predictor = b_data_subjects(n_sub).(feature);
        if length(match) < length(predictor)
            predictor = predictor(tile:2:end);
        end
        board = b_data_subjects(n_sub).('board_size');
        board = board(tile:2:end);

        match(remove1{n_sub}) = []; 
        predictor(remove1{n_sub}) = []; 
        board(remove1{n_sub}) = [];

        matches = [matches, match];
        predictors = [predictors, predictor];
        board_sizes = [board_sizes, board];
    end

    % create data to plot
    unique_sizes = unique(board_sizes);
    n_sizes = length(unique_sizes);

    % y_match = {};
    % y_mismatch = {};
    sig = zeros(n_sizes, 1);
    y_max = 0;

    n_ = 1;
    for n = 1:n_sizes
        trials_in = find(board_sizes == unique_sizes(n));
        match = matches(trials_in);
        predictor = predictors(trials_in);

        match_d = predictor(match==1);
        unmatch_d = predictor(match==0);
        p = permutationTest(match_d, unmatch_d,n_permutations);
        if p<=p_value
            h = 1; 
        else
            h = 0;
        end
        sig(n) = h;

        %y_match{n} = match_d;
        %y_mismatch{n} = unmatch_d;
        y_plot{n_} = match_d; n_ = n_ + 1;
        y_plot{n_} = unmatch_d; n_ = n_ + 1;

        y_max = max([y_max, max(match_d)]);
        y_max = max([y_max, max(unmatch_d)]);
    end

    % plot violin
    figure(n_fig)
    ngroups = n_sizes;
    nbars = 2;

    b = violin(y_plot);
    for i = 1:n_sizes
        %b(i*2-1).FaceColor = [0.33 0.51 0.21];
        b(i*2).FaceColor = 'k'; % change face color of mismatch
    end
    xticks = [1.5:2:n_sizes*2];
    names = string(sqrt(unique_sizes));

    hold on; 
    title(['tile ' num2str(tile)]) 
    feature_name = join(split(feature,'_'), '-');
    ylabel([feature_name '(clicks)']);
    xlabel('board size');
    for i = 1:ngroups
        if sig(i) == 1
            text((i*2-0.5)-0.2,y_max-1,'*','FontSize',20);
        end
    end

    set(gca,'fontsize', 20,'FontName','Arial','box','off','TickDir','out','xtick',xticks,'xticklabel',names)
    legend({'Match','','','Mismatch'},'fontsize', 20);

end