function plot_compare_match(power, artifacts, match, random_match, inter_1img_2img, t_plot, ylimits, tile, rt_diff, equalization, text_f, test_difference)
    
    % Line plot of the gamma power of match vs. mismatch trials
    % - power: n_time x n_freq x n_trials : power or all trials
    % - match: array n_trials x 1, value of 1 if match trial, 0 otherwise
    % - random_match: array n_trials x 1, value of 1 if random match, 0 otherwise
    % - inter_1img_2img: array n_trials x 1, reaction time
    % - t_plot: 1 x n_time, vector of time
    % - ylimits: y-limits of the plots
    % - tile: 1 or 2
    % - rt_diff: bool, equalization of RT and # match and mismatch trials if true
    % - equalization: bool, random equalization of # match and mismatch trials if true
    % - text_f: char, y_label
    % - test_difference: bool, whether to do permutation test or not of the
    
    addpath(genpath('../functions_general'));
    addpath(genpath('../chronux_2_12'));

    power(:, :, artifacts) = [];
    match(artifacts) = [];
    random_match(artifacts) = [];
    inter_1img_2img(artifacts) = [];
    mean_rt = mean(inter_1img_2img);

    % power match not random
    idx_m = intersect(find(match == 1), find(random_match == 0));
    % power random match
    idx_mr = intersect(find(match == 1), find(random_match == 1));
    % mismatch
    idx_u = find(match == 0);

    
    if tile == 1
        location_legend = 'northeast';
        mean_rt = -mean_rt;
        text_xlabel = 'Time from 1st tile (s)';
        [~,compare_start] = min(abs(t_plot-0)); 
        [~,compare_end] = min(abs(t_plot+mean_rt));
    else
        location_legend = 'northwest';
        text_xlabel = 'Time to 2nd tile (s)';
        [~,compare_start] = min(abs(t_plot-0)); 
        [~,compare_end] = min(abs(t_plot-1));
    end
    
    % Equalization
    if equalization
        if length(idx_m) < length(idx_u)
            rng(1)
            idx_u = randsample(idx_u, length(idx_m));
        else
            rng(1)
            idx_m = randsample(idx_m, length(idx_u));
        end
        
    end
    
    if rt_diff
        if length(idx_u) > length(idx_m)
            rt_match = inter_1img_2img(idx_m);
            rt_mismatch = inter_1img_2img(idx_u);
            m_match = mean(rt_match);
            diff_val = abs(rt_mismatch - m_match);
            [b, indx] = sort(diff_val);
            indx = indx(1:length(rt_match));
            idx_u = idx_u(indx);
        else
            rng(1)
            idx_m = randsample(idx_m, length(idx_u));
        end
    end
    idx_1 = idx_m; idx_2 = idx_u;
    
    % take match and mismatch power 
    power_1 = power(:, :, idx_1);
    S_1 = squeeze(mean(power_1,2)); S_1 = S_1'; % average over frequency
    mean_1 = mean(S_1);
    sem_1 = std(S_1)/sqrt(size(S_1,1));
    
    power_2 = power(:, :, idx_2);
    S_2 = squeeze(mean(power_2,2)); S_2 = S_2'; % average over frequency
    mean_2 = mean(S_2);
    sem_2 = std(S_2)/sqrt(size(S_2,1));
    
    % permutation test difference match and mismatch
    if test_difference
        p_value = [];
        for i = compare_start:compare_end
            p_value(i) = permutationTest(S_1(:,i),S_2(:,i),5000);
        end
        p_value(1:compare_start-1) = NaN;
        p_value(compare_end+1:end) = NaN; 
        h = p_value;
        for i = 1:length(h)
            if h(i)<=0.01
                h(i)=1;
            else
                h(i)=0;
            end
        end
        sum15 = [];
        for i = 1:(length(h)-14)
            sum15(i) = sum(h(i:i+14));
        end
        start1 = strfind([0,sum15==15],[0 1]);
        end1 = strfind([sum15==15,0],[1 0]); end1 = end1+14;

        if ismember(15,sum15)
            significant = true
        else
            significant = false;
        end
    end
    
    % Plot results    
    figure(1)

    if test_difference % plot area significantly different
        if significant==1
            for i = 1:length(start1)
                a1 = t_plot(start1(i));
                a2 = t_plot(end1(i));
                rectangle('Position',[a1,-4,a2-a1,50],'FaceColor',[1 0.949 0.8],'EdgeColor',[1 0.949 0.8])
                hold on; 
            end
        end
    end

    s1 = shadedErrorBar(t_plot,mean_1,sem_1,'lineprops',{'Color',[0.33 0.51 0.21]});
    set(s1.edge,'LineWidth',0.01)
    s1.mainLine.LineWidth = 1;
    hold on;
    s2 = shadedErrorBar(t_plot,mean_2,sem_2,'lineprops',{'Color',[0 0 0]});  
    set(s2.edge,'LineWidth',0.01)
    s2.mainLine.LineWidth = 1;

    s3 = line([-mean_rt,-mean_rt],[-4 50],'color','k','linestyle','--');
    s4 = line([0,0],[-4 50],'color','k','linestyle','-');
    s3.Annotation.LegendInformation.IconDisplayStyle = 'off';
    s4.Annotation.LegendInformation.IconDisplayStyle = 'off';

    xlim([t_plot(1) t_plot(end)])
    xlabel(text_xlabel);

    ylabel(text_f);

    lg1 = sprintf('match,n=%d', length(idx_1));
    lg2 = sprintf('mismatch,n=%d', length(idx_2)); 
    lgd = legend([s1.mainLine,s2.mainLine],{lg1,lg2},'FontSize',10,'Location',location_legend,'FontName','Arial');
    
    lgd.FontSize = 10;

    ylim(ylimits)
    xlim([t_plot(1) t_plot(end)])

    ax = gca;
    ax.FontSize = 11;
    xticks =[-3:0.5:t_plot(end)];
    set(gca,'xtick',xticks,'tickDir','out','box','off','FontName','Arial'); 
    


end